gdiffmk(1) 맨 페이지 - 윈디하나의 솔라나라

개요

섹션
맨 페이지 이름
검색(S)

gdiffmk(1)

gdiffmk(1)                  General Commands Manual                 gdiffmk(1)

Name
       gdiffmk - mark differences between groff/nroff/troff files

Synopsis
       gdiffmk [-a add-mark] [-c change-mark] [-d delete-mark] [-x diff-
               command] [-D [-B] [-M mark1 mark2]] [--] file1 file2 [output]

       gdiffmk --help

       gdiffmk --version

Description
       gdiffmk  compares two roff(7) documents, file1 and file2, and creates a
       roff document consisting of file2 with added margin character (.mc) re‐
       quests indicating output lines that differ from file1.  If the file1 or
       file2 argument is “-”, gdiffmk reads the standard input stream for that
       input.  If the output operand is present, gdiffmk writes  output  to  a
       file  of  that  name.  If it is “-” or absent, gdiffmk writes output to
       the standard output stream.  “-” cannot be both  an  input  and  output
       operand.

Options
       --help  displays  a  usage message and --version shows version informa‐
       tion; both exit afterward.

       -a add-mark
              Use add-mark for source lines not in file1 but present in file2.
              Default: “+”.

       -B     By default, the deleted texts marked by the -D option  end  with
              an  added  roff break request, .br, to ensure that the deletions
              are marked properly.  This is the only  way  to  guarantee  that
              deletions  and  small  changes get flagged.  This option directs
              the program not to insert these breaks; it makes no sense to use
              it without -D.

       -c change-mark
              Use change-mark for changed source lines.  Default: “|”.

       -d delete-mark
              Use the delete-mark for deleted source lines.  Default: “*”.

       -D     Show the deleted portions from changed and deleted text.

       -M mark1 mark2
              Change the delimiting marks for the  -D  option.   It  makes  no
              sense  to use this option without -D.  Default delimiting marks:
              “[[” ... “]]”.

       -x diff-command
              Use the diff-command command to perform the comparison of  file1
              and  file2.   In  particular, diff-command should accept the GNU
              diff(1) -D option.  Default: diff.

       --     Treat all subsequent arguments as file names, even if they begin
              with “-”.

Bugs
       The output is not necessarily compatible with all  macro  packages  and
       all  preprocessors.   A  workaround  that  often overcomes preprocessor
       problems is to run gdiffmk on the output of all the  preprocessors  in‐
       stead of the input source.

       gdiffmk  relies  on the -D option of GNU diff to make a merged “#ifdef”
       output format.  Busybox diff is known to not support it.  Also see  the
       -x diff-command option.

Authors
       gdiffmk was written by Mike Bianchi ⟨MBianchi@Foveal.com⟩, now retired.
       It is maintained by the groff developers.

See also
       groff(1), nroff(1), gtroff(1), roff(7), diff(1)



ATTRIBUTES
       See attributes(7) for descriptions of the following attributes:

       box; cbp-1 | cbp-1 l | l .  ATTRIBUTE TYPE ATTRIBUTE VALUE = Availabil‐
       ity   text/groff/groff-core = Stability Uncommitted

NOTES
       Source  code  for open source software components in Oracle Solaris can
       be found at https://www.oracle.com/downloads/opensource/solaris-source-
       code-downloads.html.

       This software was built from source available at:
       https://github.com/oracle/solaris-userland

       The original community source was downloaded from:
       https://ftp.gnu.org/gnu/groff/groff-1.23.0.tar.gz

       Further information about this software can be found on the open source
       community website at https://www.gnu.org/software/groff.

groff 1.23.0                      2 July 2023                       gdiffmk(1)
맨 페이지 내용의 저작권은 맨 페이지 작성자에게 있습니다.
RSS ATOM XHTML 5 CSS3